aboutsummaryrefslogtreecommitdiff
path: root/SRC/iparmq.f
diff options
context:
space:
mode:
authorphilippe.theveny <philippe.theveny@8a072113-8704-0410-8d35-dd094bca7971>2015-08-10 17:33:47 +0000
committerphilippe.theveny <philippe.theveny@8a072113-8704-0410-8d35-dd094bca7971>2015-08-10 17:33:47 +0000
commitadba39b8df491800ff087067cef1d54e36ad659c (patch)
tree3bf3e8a1691e8cc779cbad1758521f7535f2e295 /SRC/iparmq.f
parent7b9b17997ea18c8a3689c6ebb318c78956e99406 (diff)
Bux fix from Rodney James about implicit typing.
Some variables were undeclared, some were mistyped, and others were unused.
Diffstat (limited to 'SRC/iparmq.f')
-rw-r--r--SRC/iparmq.f4
1 files changed, 2 insertions, 2 deletions
diff --git a/SRC/iparmq.f b/SRC/iparmq.f
index 581e1cb1..6aea872a 100644
--- a/SRC/iparmq.f
+++ b/SRC/iparmq.f
@@ -33,7 +33,7 @@
*> This program sets problem and machine dependent parameters
*> useful for xHSEQR and related subroutines for eigenvalue
*> problems. It is called whenever
*> ILAENV is called with 12 <= ISPEC <= 16
*> \endverbatim
*
* Arguments:
@@ -318,7 +318,7 @@
*
* Convert NAME to upper case if the first character is lower case.
*
- ILAENV = 0
+ IPARMQ = 0
SUBNAM = NAME
IC = ICHAR( SUBNAM( 1: 1 ) )
IZ = ICHAR( 'Z' )
@@ -33,7 +33,7 @@
*> useful for xHSEQR and related subroutines for eigenvalue
*> problems. It is called whenever
-*> ILAENV is called with 12 <= ISPEC <= 16
+*> IPARMQ is called with 12 <= ISPEC <= 16
*> \endverbatim
*